==> nomachine-7.8.2-1-x86_64.pkg.tar.zst: NX/lib/perl/nxserver/NXConnectionPolicy.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2022 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXSERVER, NX protocol compression and NX extensions to this software    #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
sub NXConnectionPolicy::BEGIN{package NXConnectionPolicy;no warnings;require 
NXServices;do{"\x4e\x58\x53\x65\x72\x76\x69\x63\x65\x73"->import};}sub 
NXConnectionPolicy::BEGIN{package NXConnectionPolicy;no warnings;require NXMsg;
do{"\x4e\x58\x4d\x73\x67"->import};}sub 
NXConnectionPolicy::__setDefaultPolicyValues{package NXConnectionPolicy;no 
warnings;(my $ref_autocreate=shift (@_));(my $ref_autoconnect=shift (@_));(my $ref_automigrate
=shift (@_));(my $ref_desktop=shift (@_));(my $ref_dialog=shift (@_));(my $ref_xsessions
=shift (@_));(my $ref_udp=shift (@_));if (Server::isReverseDefaultDesktopPolicy 
()){($$ref_autocreate="\x6e\x6f");($$ref_autoconnect="\x6e\x6f");(
$$ref_automigrate="\x6e\x6f");($$ref_desktop="\x79\x65\x73");($$ref_dialog=
"\x6e\x6f");($$ref_xsessions="\x79\x65\x73");($$ref_udp="\x79\x65\x73");}else{(
$$ref_autocreate="\x79\x65\x73");($$ref_autoconnect="\x79\x65\x73");(
$$ref_automigrate="\x79\x65\x73");($$ref_desktop="\x6e\x6f");($$ref_dialog=
"\x6e\x6f");($$ref_xsessions="\x6e\x6f");($$ref_udp="\x79\x65\x73");}}sub 
NXConnectionPolicy::getConnectionPolicyValues{package NXConnectionPolicy;no 
warnings;my ($autocreate,$autoconnect,$automigrate,$desktop,$dialog,$xsessions,
$udp);__setDefaultPolicyValues ((\$autocreate),(\$autoconnect),(\$automigrate),(
\$desktop),(\$dialog),(\$xsessions),(\$udp));if (($GLOBAL::ConnectPolicy eq 
"\x6e\x6f\x74\x53\x65\x74")){if (Server::isReverseDefaultDesktopPolicy ()){(
$GLOBAL::ConnectPolicyDesktop=(0x02f0+ 985-0x06c9));}return ($autocreate,
$autoconnect,$automigrate,$desktop,$dialog,$xsessions,$udp);}(my (@parameters)=
split ( /,/ ,$GLOBAL::ConnectPolicy,(0x13a2+ 3990-0x2338)));foreach my $value (
@parameters){if (($value eq "\x61\x75\x74\x6f\x63\x72\x65\x61\x74\x65\x3d\x31"))
{($autocreate="\x79\x65\x73");}elsif (($value eq 
"\x61\x75\x74\x6f\x63\x72\x65\x61\x74\x65\x3d\x30")){($autocreate="\x6e\x6f");}
if (($value eq "\x61\x75\x74\x6f\x63\x6f\x6e\x6e\x65\x63\x74\x3d\x31")){(
$autoconnect="\x79\x65\x73");}elsif (($value eq 
"\x61\x75\x74\x6f\x63\x6f\x6e\x6e\x65\x63\x74\x3d\x30")){($autoconnect=
"\x6e\x6f");}if (($value eq 
"\x61\x75\x74\x6f\x6d\x69\x67\x72\x61\x74\x65\x3d\x31")){($automigrate=
"\x79\x65\x73");}elsif (($value eq 
"\x61\x75\x74\x6f\x6d\x69\x67\x72\x61\x74\x65\x3d\x30")){($automigrate=
"\x6e\x6f");}if (($value eq "\x64\x65\x73\x6b\x74\x6f\x70\x3d\x31")){(
$GLOBAL::ConnectPolicyDesktop=(0x137c+ 2574-0x1d89));($desktop="\x79\x65\x73");}
elsif (($value eq "\x64\x65\x73\x6b\x74\x6f\x70\x3d\x30")){(
$GLOBAL::ConnectPolicyDesktop=(0x0799+ 6950-0x22bf));($desktop="\x6e\x6f");}if (
($value eq "\x64\x69\x61\x6c\x6f\x67\x3d\x31")){($dialog="\x79\x65\x73");}elsif 
(($value eq "\x64\x69\x61\x6c\x6f\x67\x3d\x30")){($dialog="\x6e\x6f");}if ((
$value eq "\x78\x73\x65\x73\x73\x69\x6f\x6e\x73\x3d\x31")){($xsessions=
"\x79\x65\x73");}elsif (($value eq 
"\x78\x73\x65\x73\x73\x69\x6f\x6e\x73\x3d\x30")){($xsessions="\x6e\x6f");}if ((
$value eq "\x75\x64\x70\x3d\x31")){($udp="\x79\x65\x73");}elsif (($value eq 
"\x75\x64\x70\x3d\x30")){($udp="\x6e\x6f");}}return ($autocreate,$autoconnect,
$automigrate,$desktop,$dialog,$xsessions,$udp);}sub 
NXConnectionPolicy::formatConnectionPolicyOutput{package NXConnectionPolicy;no 
warnings;my (@out_resources);(my ($autocreate,$autoconnect,$automigrate,$desktop
,$dialog,$xsessions,$udp)=getConnectionPolicyValues ());push (@out_resources,
sprintf (
"\x25\x2d\x32\x34\x2e\x32\x34\x73\x20\x20\x20\x20\x25\x2d\x36\x2e\x36\x73\x0a",
"\x61\x75\x74\x6f\x63\x72\x65\x61\x74\x65",$autocreate));push (@out_resources,
sprintf (
"\x25\x2d\x32\x34\x2e\x32\x34\x73\x20\x20\x20\x20\x25\x2d\x36\x2e\x36\x73\x0a",
"\x61\x75\x74\x6f\x63\x6f\x6e\x6e\x65\x63\x74",$autoconnect));push (
@out_resources,sprintf (
"\x25\x2d\x32\x34\x2e\x32\x34\x73\x20\x20\x20\x20\x25\x2d\x36\x2e\x36\x73\x0a",
"\x61\x75\x74\x6f\x6d\x69\x67\x72\x61\x74\x65",$automigrate));push (
@out_resources,sprintf (
"\x25\x2d\x32\x34\x2e\x32\x34\x73\x20\x20\x20\x20\x25\x2d\x36\x2e\x36\x73\x0a",
"\x64\x65\x73\x6b\x74\x6f\x70",$desktop));if (
Server::isClientSupportingDialogInConnectionPolicy ()){push (@out_resources,
sprintf (
"\x25\x2d\x32\x34\x2e\x32\x34\x73\x20\x20\x20\x20\x25\x2d\x36\x2e\x36\x73\x0a",
"\x64\x69\x61\x6c\x6f\x67",$dialog));}if (
Server::isClientSupportsSystemDesktopsInConnectionPolicy ()){push (
@out_resources,sprintf (
"\x25\x2d\x32\x34\x2e\x32\x34\x73\x20\x20\x20\x20\x25\x2d\x36\x2e\x36\x73\x0a",
"\x78\x73\x65\x73\x73\x69\x6f\x6e\x73",$xsessions));}if (
Server::isClientSupportsUdpInConnectionPolicy ()){push (@out_resources,sprintf (
"\x25\x2d\x32\x34\x2e\x32\x34\x73\x20\x20\x20\x20\x25\x2d\x36\x2e\x36\x73\x0a",
"\x75\x64\x70",$udp));}return (@out_resources);}sub 
NXConnectionPolicy::printConnactionPolicy{package NXConnectionPolicy;no warnings
;(my (@param)=@_);my (%parameters);if (((Server::isClientNxwebclient ()||
Server::isClientNxclient ())and (not (Server::isClientVersion3OrOlder ())))){(my (
@resources)=formatConnectionPolicyOutput ());NXMsg::send_response (
"\x69\x43\x6f\x6e\x6e\x65\x63\x74\x69\x6f\x6e\x50\x6f\x6c\x69\x63\x79",
"\x4e\x58\x43\x6f\x6e\x6e\x65\x63\x74\x69\x6f\x6e\x50\x6f\x6c\x69\x63\x79");
main::nxwrite (main::nxgetSTDOUT (),"\x0a");main::nxwrite (main::nxgetSTDOUT (),
"\x54\x79\x70\x65\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x56\x61\x6c\x75\x65\x0a"
);main::nxwrite (main::nxgetSTDOUT (),
"\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x20\x20\x20\x20\x2d\x2d\x2d\x2d\x2d\x2d\x0a"
);foreach my $res (@resources){main::nxwrite (main::nxgetSTDOUT (),$res);}}
return ((0x03fd+ 1327-0x092c));}sub NXConnectionPolicy::isDesktopEnabled{package
 NXConnectionPolicy;no warnings;getConnectionPolicyValues ();if ((
$GLOBAL::ConnectPolicyDesktop==(0x0577+ 7283-0x21e9))){return (
(0x19ff+  40-0x1a26));}return ((0x03d1+ 8423-0x24b8));}sub 
NXConnectionPolicy::isSystemDesktopsEnabled{package NXConnectionPolicy;no 
warnings;(my ($autocreate,$autoconnect,$automigrate,$desktop,$dialog,$xsessions,
$udp)=getConnectionPolicyValues ());if ((not (
Server::isClientSupportsSystemDesktopsInConnectionPolicy ()))){return (
(0x02dd+  12-0x02e9));}if (($xsessions eq "\x79\x65\x73")){return (
(0x1e60+ 188-0x1f1b));}return ((0x0244+ 5760-0x18c4));}package 
NXConnectionPolicy;no warnings;NXMsg::register_response (
"\x4e\x58\x43\x6f\x6e\x6e\x65\x63\x74\x69\x6f\x6e\x50\x6f\x6c\x69\x63\x79",
"\x69\x43\x6f\x6e\x6e\x65\x63\x74\x69\x6f\x6e\x50\x6f\x6c\x69\x63\x79",
(0x1270+ 1869-0x1919));return ((0x05aa+ 6483-0x1efc));

==> nomachine-7.9.2-1-x86_64.pkg.tar.zst: NX/lib/perl/nxserver/NXConnectionPolicy.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2022 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXSERVER, NX protocol compression and NX extensions to this software    #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
sub NXConnectionPolicy::BEGIN{package NXConnectionPolicy;no warnings;require 
NXServices;do{"\x4e\x58\x53\x65\x72\x76\x69\x63\x65\x73"->import};}sub 
NXConnectionPolicy::BEGIN{package NXConnectionPolicy;no warnings;require NXMsg;
do{"\x4e\x58\x4d\x73\x67"->import};}sub 
NXConnectionPolicy::__setDefaultPolicyValues{package NXConnectionPolicy;no 
warnings;(my $ref_autocreate=shift (@_));(my $ref_autoconnect=shift (@_));(my $ref_automigrate
=shift (@_));(my $ref_desktop=shift (@_));(my $ref_dialog=shift (@_));(my $ref_xsessions
=shift (@_));(my $ref_udp=shift (@_));if (Server::isReverseDefaultDesktopPolicy 
()){($$ref_autocreate="\x6e\x6f");($$ref_autoconnect="\x6e\x6f");(
$$ref_automigrate="\x6e\x6f");($$ref_desktop="\x79\x65\x73");($$ref_dialog=
"\x6e\x6f");($$ref_xsessions="\x79\x65\x73");($$ref_udp="\x79\x65\x73");}else{(
$$ref_autocreate="\x79\x65\x73");($$ref_autoconnect="\x79\x65\x73");(
$$ref_automigrate="\x79\x65\x73");($$ref_desktop="\x6e\x6f");($$ref_dialog=
"\x6e\x6f");($$ref_xsessions="\x6e\x6f");($$ref_udp="\x79\x65\x73");}}sub 
NXConnectionPolicy::getConnectionPolicyValues{package NXConnectionPolicy;no 
warnings;my ($autocreate,$autoconnect,$automigrate,$desktop,$dialog,$xsessions,
$udp);__setDefaultPolicyValues ((\$autocreate),(\$autoconnect),(\$automigrate),(
\$desktop),(\$dialog),(\$xsessions),(\$udp));if (($GLOBAL::ConnectPolicy eq 
"\x6e\x6f\x74\x53\x65\x74")){if (Server::isReverseDefaultDesktopPolicy ()){(
$GLOBAL::ConnectPolicyDesktop=(0x03bb+ 5459-0x190e));}return ($autocreate,
$autoconnect,$automigrate,$desktop,$dialog,$xsessions,$udp);}(my (@parameters)=
split ( /,/ ,$GLOBAL::ConnectPolicy,(0x1357+ 404-0x14eb)));foreach my $value (
@parameters){if (($value eq "\x61\x75\x74\x6f\x63\x72\x65\x61\x74\x65\x3d\x31"))
{($autocreate="\x79\x65\x73");}elsif (($value eq 
"\x61\x75\x74\x6f\x63\x72\x65\x61\x74\x65\x3d\x30")){($autocreate="\x6e\x6f");}
if (($value eq "\x61\x75\x74\x6f\x63\x6f\x6e\x6e\x65\x63\x74\x3d\x31")){(
$autoconnect="\x79\x65\x73");}elsif (($value eq 
"\x61\x75\x74\x6f\x63\x6f\x6e\x6e\x65\x63\x74\x3d\x30")){($autoconnect=
"\x6e\x6f");}if (($value eq 
"\x61\x75\x74\x6f\x6d\x69\x67\x72\x61\x74\x65\x3d\x31")){($automigrate=
"\x79\x65\x73");}elsif (($value eq 
"\x61\x75\x74\x6f\x6d\x69\x67\x72\x61\x74\x65\x3d\x30")){($automigrate=
"\x6e\x6f");}if (($value eq "\x64\x65\x73\x6b\x74\x6f\x70\x3d\x31")){(
$GLOBAL::ConnectPolicyDesktop=(0x161c+ 4002-0x25bd));($desktop="\x79\x65\x73");}
elsif (($value eq "\x64\x65\x73\x6b\x74\x6f\x70\x3d\x30")){(
$GLOBAL::ConnectPolicyDesktop=(0x1480+ 3430-0x21e6));($desktop="\x6e\x6f");}if (
($value eq "\x64\x69\x61\x6c\x6f\x67\x3d\x31")){($dialog="\x79\x65\x73");}elsif 
(($value eq "\x64\x69\x61\x6c\x6f\x67\x3d\x30")){($dialog="\x6e\x6f");}if ((
$value eq "\x78\x73\x65\x73\x73\x69\x6f\x6e\x73\x3d\x31")){($xsessions=
"\x79\x65\x73");}elsif (($value eq 
"\x78\x73\x65\x73\x73\x69\x6f\x6e\x73\x3d\x30")){($xsessions="\x6e\x6f");}if ((
$value eq "\x75\x64\x70\x3d\x31")){($udp="\x79\x65\x73");}elsif (($value eq 
"\x75\x64\x70\x3d\x30")){($udp="\x6e\x6f");}}return ($autocreate,$autoconnect,
$automigrate,$desktop,$dialog,$xsessions,$udp);}sub 
NXConnectionPolicy::formatConnectionPolicyOutput{package NXConnectionPolicy;no 
warnings;my (@out_resources);(my ($autocreate,$autoconnect,$automigrate,$desktop
,$dialog,$xsessions,$udp)=getConnectionPolicyValues ());push (@out_resources,
sprintf (
"\x25\x2d\x32\x34\x2e\x32\x34\x73\x20\x20\x20\x20\x25\x2d\x36\x2e\x36\x73\x0a",
"\x61\x75\x74\x6f\x63\x72\x65\x61\x74\x65",$autocreate));push (@out_resources,
sprintf (
"\x25\x2d\x32\x34\x2e\x32\x34\x73\x20\x20\x20\x20\x25\x2d\x36\x2e\x36\x73\x0a",
"\x61\x75\x74\x6f\x63\x6f\x6e\x6e\x65\x63\x74",$autoconnect));push (
@out_resources,sprintf (
"\x25\x2d\x32\x34\x2e\x32\x34\x73\x20\x20\x20\x20\x25\x2d\x36\x2e\x36\x73\x0a",
"\x61\x75\x74\x6f\x6d\x69\x67\x72\x61\x74\x65",$automigrate));push (
@out_resources,sprintf (
"\x25\x2d\x32\x34\x2e\x32\x34\x73\x20\x20\x20\x20\x25\x2d\x36\x2e\x36\x73\x0a",
"\x64\x65\x73\x6b\x74\x6f\x70",$desktop));if (
Server::isClientSupportingDialogInConnectionPolicy ()){push (@out_resources,
sprintf (
"\x25\x2d\x32\x34\x2e\x32\x34\x73\x20\x20\x20\x20\x25\x2d\x36\x2e\x36\x73\x0a",
"\x64\x69\x61\x6c\x6f\x67",$dialog));}if (
Server::isClientSupportsSystemDesktopsInConnectionPolicy ()){push (
@out_resources,sprintf (
"\x25\x2d\x32\x34\x2e\x32\x34\x73\x20\x20\x20\x20\x25\x2d\x36\x2e\x36\x73\x0a",
"\x78\x73\x65\x73\x73\x69\x6f\x6e\x73",$xsessions));}if (
Server::isClientSupportsUdpInConnectionPolicy ()){push (@out_resources,sprintf (
"\x25\x2d\x32\x34\x2e\x32\x34\x73\x20\x20\x20\x20\x25\x2d\x36\x2e\x36\x73\x0a",
"\x75\x64\x70",$udp));}return (@out_resources);}sub 
NXConnectionPolicy::printConnactionPolicy{package NXConnectionPolicy;no warnings
;(my (@param)=@_);my (%parameters);if (((Server::isClientNxwebclient ()||
Server::isClientNxclient ())and (not (Server::isClientVersion3OrOlder ())))){(my (
@resources)=formatConnectionPolicyOutput ());NXMsg::send_response (
"\x69\x43\x6f\x6e\x6e\x65\x63\x74\x69\x6f\x6e\x50\x6f\x6c\x69\x63\x79",
"\x4e\x58\x43\x6f\x6e\x6e\x65\x63\x74\x69\x6f\x6e\x50\x6f\x6c\x69\x63\x79");
main::nxwrite (main::nxgetSTDOUT (),"\x0a");main::nxwrite (main::nxgetSTDOUT (),
"\x54\x79\x70\x65\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x56\x61\x6c\x75\x65\x0a"
);main::nxwrite (main::nxgetSTDOUT (),
"\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x20\x20\x20\x20\x2d\x2d\x2d\x2d\x2d\x2d\x0a"
);foreach my $res (@resources){main::nxwrite (main::nxgetSTDOUT (),$res);}}
return ((0x0bb6+ 4783-0x1e65));}sub NXConnectionPolicy::isDesktopEnabled{package
 NXConnectionPolicy;no warnings;getConnectionPolicyValues ();if ((
$GLOBAL::ConnectPolicyDesktop==(0x1fd4+ 1440-0x2573))){return (
(0x1e92+ 1548-0x249d));}return ((0x1b06+ 124-0x1b82));}sub 
NXConnectionPolicy::isSystemDesktopsEnabled{package NXConnectionPolicy;no 
warnings;(my ($autocreate,$autoconnect,$automigrate,$desktop,$dialog,$xsessions,
$udp)=getConnectionPolicyValues ());if ((not (
Server::isClientSupportsSystemDesktopsInConnectionPolicy ()))){return (
(0x0187+ 8637-0x2344));}if (($xsessions eq "\x79\x65\x73")){return (
(0x0cef+ 368-0x0e5e));}return ((0x133d+ 4371-0x2450));}package 
NXConnectionPolicy;no warnings;NXMsg::register_response (
"\x4e\x58\x43\x6f\x6e\x6e\x65\x63\x74\x69\x6f\x6e\x50\x6f\x6c\x69\x63\x79",
"\x69\x43\x6f\x6e\x6e\x65\x63\x74\x69\x6f\x6e\x50\x6f\x6c\x69\x63\x79",
(0x0bd2+ 2579-0x1541));return ((0x0852+ 4215-0x18c8));
